@@ -10,16 +10,15 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
-""" Test the ZVC machinery
-
-$Id$
-"""
+"""Test the ZVC machinery."""
 import unittest
 
-from .common import get_transaction
+import transaction
+
+from .common import common_commit
 from .common import common_setUp
 from .common import common_tearDown
-from .common import common_commit
+
 
 class VersionControlTests(unittest.TestCase):
 
@@ -39,7 +38,6 @@ class VersionControlTests(unittest.TestCase):
         self.assertFalse(repository.isAVersionableResource('foobar'))
         self.assertFalse(repository.isAVersionableResource(self))
 
-
     def testIsUnderVersionControl(self):
         # Test checking whether an object is under version control.
         repository = self.repository
@@ -49,7 +47,6 @@ class VersionControlTests(unittest.TestCase):
         self.commit()
         self.assertTrue(repository.isUnderVersionControl(document))
 
-
     def testIsResourceUpToDate(self):
         # Test checking whether a versioned resource is up to date.
         repository = self.repository
@@ -73,7 +70,6 @@ class VersionControlTests(unittest.TestCase):
         self.commit()
         self.assertTrue(repository.isResourceUpToDate(document))
 
-
     def testIsResourceChanged(self):
         # Test checking whether a versioned resource has changed.
         repository = self.repository
@@ -97,7 +93,6 @@ class VersionControlTests(unittest.TestCase):
         if self.do_commits:
             self.assertFalse(repository.isResourceChanged(document))
 
-
     def testVersionBookkeeping(self):
         # Check the consistency of the version bookkeeping info.
         repository = self.repository
@@ -106,26 +101,26 @@ class VersionControlTests(unittest.TestCase):
         self.commit()
 
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.user_id == 'UnitTester')
-        self.assertTrue(info.status == info.CHECKED_IN)
-        self.assertTrue(info.sticky == None)
+        self.assertEqual(info.user_id, 'UnitTester')
+        self.assertEqual(info.status, info.CHECKED_IN)
+        self.assertIsNone(info.sticky)
         first_version = info.version_id
 
         document = repository.checkoutResource(document)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.status == info.CHECKED_OUT)
+        self.assertEqual(info.status, info.CHECKED_OUT)
 
         document = repository.checkinResource(document, '')
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.status == info.CHECKED_IN)
+        self.assertEqual(info.status, info.CHECKED_IN)
 
         document = repository.updateResource(document, first_version)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.status == info.CHECKED_IN)
-        self.assertTrue(info.version_id == first_version)
+        self.assertEqual(info.status, info.CHECKED_IN)
+        self.assertEqual(info.version_id, first_version)
 
         branch_name = 'Bug Fix Branch'
         repository.makeActivity(document, branch_name)
@@ -133,17 +128,17 @@ class VersionControlTests(unittest.TestCase):
         document = repository.updateResource(document, branch_name)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.sticky == ('B', branch_name))
+        self.assertEqual(info.sticky, ('B', branch_name))
 
         document = repository.updateResource(document, 'mainline')
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.sticky == None)
+        self.assertIsNone(info.sticky)
 
         document = repository.checkoutResource(document)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.status == info.CHECKED_OUT)
+        self.assertEqual(info.status, info.CHECKED_OUT)
 
         document.manage_edit('change 1', '')
         self.commit()
@@ -151,8 +146,7 @@ class VersionControlTests(unittest.TestCase):
         document = repository.uncheckoutResource(document)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.status == info.CHECKED_IN)
-
+        self.assertEqual(info.status, info.CHECKED_IN)
 
     def testApplyVersionControl(self):
         # Test checking whether a versioned resource is up to date.
@@ -165,19 +159,18 @@ class VersionControlTests(unittest.TestCase):
 
         # Make sure we can't do it a second time.
         self.assertRaises(VersionControlError,
-                              repository.applyVersionControl,
-                              document
-                              )
+                          repository.applyVersionControl,
+                          document
+                          )
 
         info = repository.getVersionInfo(document)
 
         # Check that the last log entry record is what we expect.
         record = repository.getLogEntries(document)[0]
-        self.assertTrue(record.version_id == info.version_id)
-        self.assertTrue(record.user_id == 'UnitTester')
-        self.assertTrue(record.action == record.ACTION_CHECKIN)
-        self.assertTrue(record.path == '/folder1/folder2/document1')
-
+        self.assertEqual(record.version_id, info.version_id)
+        self.assertEqual(record.user_id, 'UnitTester')
+        self.assertEqual(record.action, record.ACTION_CHECKIN)
+        self.assertEqual(record.path, '/folder1/folder2/document1')
 
     def testCheckoutResource(self):
         # Test checking out a version controlled resource.
@@ -195,16 +188,16 @@ class VersionControlTests(unittest.TestCase):
 
         # Make sure you can't checkout a checked-out resource.
         self.assertRaises(VersionControlError,
-                              repository.checkoutResource,
-                              document
-                              )
+                          repository.checkoutResource,
+                          document
+                          )
 
         # Check that the last log entry record is what we expect.
         record = repository.getLogEntries(document)[0]
-        self.assertTrue(record.version_id == first_version)
-        self.assertTrue(record.user_id == 'UnitTester')
-        self.assertTrue(record.action == record.ACTION_CHECKOUT)
-        self.assertTrue(record.path == '/folder1/folder2/document1')
+        self.assertEqual(record.version_id, first_version)
+        self.assertEqual(record.user_id, 'UnitTester')
+        self.assertEqual(record.action, record.ACTION_CHECKOUT)
+        self.assertEqual(record.path, '/folder1/folder2/document1')
 
         document = repository.checkinResource(document, '')
         self.commit()
@@ -213,17 +206,16 @@ class VersionControlTests(unittest.TestCase):
 
         # Make sure you can't checkout a non-up-to-date resource.
         self.assertRaises(VersionControlError,
-                              repository.checkoutResource,
-                              document
-                              )
+                          repository.checkoutResource,
+                          document
+                          )
 
         # Check that the last log entry record is what we expect.
         record = repository.getLogEntries(document)[0]
-        self.assertTrue(record.version_id == first_version)
-        self.assertTrue(record.user_id == 'UnitTester')
-        self.assertTrue(record.action == record.ACTION_UPDATE)
-        self.assertTrue(record.path == '/folder1/folder2/document1')
-
+        self.assertEqual(record.version_id, first_version)
+        self.assertEqual(record.user_id, 'UnitTester')
+        self.assertEqual(record.action, record.ACTION_UPDATE)
+        self.assertEqual(record.path, '/folder1/folder2/document1')
 
     def testCheckinResource(self):
         # Test checking in a version controlled resource.
@@ -235,9 +227,9 @@ class VersionControlTests(unittest.TestCase):
 
         # Make sure you can't checkin a checked-in resource.
         self.assertRaises(VersionControlError,
-                              repository.checkinResource,
-                              document, ''
-                              )
+                          repository.checkinResource,
+                          document, ''
+                          )
 
         info = repository.getVersionInfo(document)
         first_version = info.version_id
@@ -251,28 +243,26 @@ class VersionControlTests(unittest.TestCase):
         # Check that the last log entry record is what we expect.
         record = repository.getLogEntries(document)[0]
         info = repository.getVersionInfo(document)
-        self.assertTrue(record.version_id == info.version_id)
-        self.assertTrue(record.user_id == 'UnitTester')
-        self.assertTrue(record.action == record.ACTION_CHECKIN)
-        self.assertTrue(record.path == '/folder1/folder2/document1')
+        self.assertEqual(record.version_id, info.version_id)
+        self.assertEqual(record.user_id, 'UnitTester')
+        self.assertEqual(record.action, record.ACTION_CHECKIN)
+        self.assertEqual(record.path, '/folder1/folder2/document1')
 
         self.assertRaises(VersionControlError,
-                              repository.checkinResource,
-                              document, ''
-                              )
+                          repository.checkinResource,
+                          document, ''
+                          )
 
         document = repository.updateResource(document, first_version)
         self.commit()
 
         self.assertRaises(VersionControlError,
-                              repository.checkinResource,
-                              document, ''
-                              )
-
+                          repository.checkinResource,
+                          document, ''
+                          )
 
     def testUncheckoutResource(self):
         # Test uncheckout of a version controlled resource.
-        from Products.ZopeVersionControl.Utility import VersionControlError
         repository = self.repository
 
         document = repository.applyVersionControl(self.document1)
@@ -290,19 +280,17 @@ class VersionControlTests(unittest.TestCase):
         self.commit()
 
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.status == info.CHECKED_IN)
+        self.assertEqual(info.status, info.CHECKED_IN)
 
         # Check that the last log entry record is what we expect.
         record = repository.getLogEntries(document)[0]
-        self.assertTrue(record.version_id == first_version)
-        self.assertTrue(record.user_id == 'UnitTester')
-        self.assertTrue(record.action == record.ACTION_UNCHECKOUT)
-        self.assertTrue(record.path == '/folder1/folder2/document1')
-
+        self.assertEqual(record.version_id, first_version)
+        self.assertEqual(record.user_id, 'UnitTester')
+        self.assertEqual(record.action, record.ACTION_UNCHECKOUT)
+        self.assertEqual(record.path, '/folder1/folder2/document1')
 
     def testUpdateResource(self):
         # Test updating a version controlled resource.
-        from Products.ZopeVersionControl.Utility import VersionControlError
         repository = self.repository
 
         document = repository.applyVersionControl(self.document1)
@@ -322,7 +310,7 @@ class VersionControlTests(unittest.TestCase):
         document = repository.updateResource(document, first_version)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.version_id == first_version)
+        self.assertEqual(info.version_id, first_version)
 
         document = repository.updateResource(document, None)
         self.commit()
@@ -330,15 +318,14 @@ class VersionControlTests(unittest.TestCase):
         document = repository.updateResource(document, 'First Version')
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.version_id == first_version)
+        self.assertEqual(info.version_id, first_version)
 
         # Check that the last log entry record is what we expect.
         record = repository.getLogEntries(document)[0]
-        self.assertTrue(record.version_id == first_version)
-        self.assertTrue(record.user_id == 'UnitTester')
-        self.assertTrue(record.action == record.ACTION_UPDATE)
-        self.assertTrue(record.path == '/folder1/folder2/document1')
-
+        self.assertEqual(record.version_id, first_version)
+        self.assertEqual(record.user_id, 'UnitTester')
+        self.assertEqual(record.action, record.ACTION_UPDATE)
+        self.assertEqual(record.path, '/folder1/folder2/document1')
 
     def testLabelResource(self):
         # Test labeling a version controlled resource.
@@ -357,9 +344,9 @@ class VersionControlTests(unittest.TestCase):
         self.commit()
 
         self.assertRaises(VersionControlError,
-                              repository.labelResource,
-                              document, 'First Version', 1
-                              )
+                          repository.labelResource,
+                          document, 'First Version', 1
+                          )
 
         document = repository.uncheckoutResource(document)
         self.commit()
@@ -367,14 +354,14 @@ class VersionControlTests(unittest.TestCase):
         repository.makeActivity(document, 'Activity 1')
 
         self.assertRaises(VersionControlError,
-                              repository.labelResource,
-                              document, 'mainline', 1
-                              )
+                          repository.labelResource,
+                          document, 'mainline', 1
+                          )
 
         self.assertRaises(VersionControlError,
-                              repository.labelResource,
-                              document, 'Activity 1', 1
-                              )
+                          repository.labelResource,
+                          document, 'Activity 1', 1
+                          )
 
         document = repository.checkoutResource(document)
         self.commit()
@@ -383,15 +370,14 @@ class VersionControlTests(unittest.TestCase):
         self.commit()
 
         self.assertRaises(VersionControlError,
-                              repository.labelResource,
-                              document, 'First Version', 0
-                              )
+                          repository.labelResource,
+                          document, 'First Version', 0
+                          )
 
         document = repository.updateResource(document, 'First Version')
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.version_id == first_version)
-
+        self.assertEqual(info.version_id, first_version)
 
     def testActivityAPI(self):
         from Products.ZopeVersionControl.Utility import VersionControlError
@@ -408,7 +394,7 @@ class VersionControlTests(unittest.TestCase):
             self.assertFalse(repository.isResourceChanged(document))
 
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.sticky == None)
+        self.assertTrue(info.sticky is None)
         first_version = info.version_id
 
         activity_name = 'My Big Project'
@@ -418,9 +404,9 @@ class VersionControlTests(unittest.TestCase):
 
         # Make sure we can't do it again for the same activity id.
         self.assertRaises(VersionControlError,
-                              repository.makeActivity,
-                              document, activity_name
-                              )
+                          repository.makeActivity,
+                          document, activity_name
+                          )
 
         document = repository.updateResource(document, activity_name)
         self.commit()
@@ -430,8 +416,8 @@ class VersionControlTests(unittest.TestCase):
             self.assertFalse(repository.isResourceChanged(document))
 
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.version_id == first_version)
-        self.assertTrue(info.sticky == ('B', activity_name))
+        self.assertEqual(info.version_id, first_version)
+        self.assertEqual(info.sticky, ('B', activity_name))
 
         repository.checkoutResource(document)
         self.commit()
@@ -443,7 +429,7 @@ class VersionControlTests(unittest.TestCase):
         self.commit()
 
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.sticky == ('B', activity_name))
+        self.assertEqual(info.sticky, ('B', activity_name))
 
         for n in range(10):
             activity_name = 'Activity %d' % n
@@ -460,8 +446,8 @@ class VersionControlTests(unittest.TestCase):
             self.assertTrue(repository.isResourceUpToDate(document))
 
             info = repository.getVersionInfo(document)
-            self.assertTrue(info.sticky == ('B', activity_name))
-            self.assertTrue(info.version_id == root_version)
+            self.assertEqual(info.sticky, ('B', activity_name))
+            self.assertEqual(info.version_id, root_version)
 
             repository.checkoutResource(document)
             self.commit()
@@ -471,12 +457,12 @@ class VersionControlTests(unittest.TestCase):
 
             document = repository.checkinResource(
                 document, 'activity change %d' % n
-                )
+            )
             self.commit()
 
             info = repository.getVersionInfo(document)
-            self.assertTrue(info.sticky == ('B', activity_name))
-            self.assertFalse(info.version_id == root_version)
+            self.assertEqual(info.sticky, ('B', activity_name))
+            self.assertNotEqual(info.version_id, root_version)
 
         document = repository.updateResource(document, root_version)
         self.commit()
@@ -488,13 +474,8 @@ class VersionControlTests(unittest.TestCase):
 
 #        self.assertTrue(repository.isResourceUpToDate(document))
 
-
-
-
     def testSelectionByDate(self):
         # Test selection of versions by date.
-        from Products.ZopeVersionControl.Utility import VersionControlError
-        from DateTime.DateTime import DateTime
         import time
 
         repository = self.repository
@@ -546,7 +527,7 @@ class VersionControlTests(unittest.TestCase):
         document = repository.updateResource(document, target_time)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.version_id == first_version)
+        self.assertEqual(info.version_id, first_version)
 
         # Now do some branching and make sure we backtrack correctly
         # through the branch lineage when doing date selection.
@@ -570,8 +551,7 @@ class VersionControlTests(unittest.TestCase):
         document = repository.updateResource(document, target_time)
         self.commit()
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.version_id == first_version)
-
+        self.assertEqual(info.version_id, first_version)
 
     def testSelectionByLabel(self):
         # Test labeling and selection of versions using labels.
@@ -594,8 +574,8 @@ class VersionControlTests(unittest.TestCase):
         for label, version_id in label_set:
             document = repository.updateResource(document, label)
             info = repository.getVersionInfo(document)
-            self.assertTrue(info.version_id == version_id)
-            self.assertTrue(info.sticky == ('L', label))
+            self.assertEqual(info.version_id, version_id)
+            self.assertEqual(info.sticky, ('L', label))
 
         # Ensure that label moving works as expected and that we get an
         # error if we try to reuse a label without forcing a label move.
@@ -603,24 +583,21 @@ class VersionControlTests(unittest.TestCase):
         repository.labelResource(document, 'change 1', force=1)
         document = repository.updateResource(document, 'change 1')
         info = repository.getVersionInfo(document)
-        self.assertTrue(info.version_id == label_set[0][1])
+        self.assertEqual(info.version_id, label_set[0][1])
 
         self.assertRaises(VersionControlError,
-                              repository.labelResource,
-                              document, 'change 3'
-                              )
-
+                          repository.labelResource,
+                          document, 'change 3'
+                          )
 
     def testGetVersionOfResource(self):
         # Test retrieving specific versions of resources.
-        from Products.ZopeVersionControl.Utility import VersionControlError
         repository = self.repository
 
         document = repository.applyVersionControl(self.document1)
         self.commit()
 
         info = repository.getVersionInfo(document)
-        history_id = info.history_id
         first_version = info.version_id
 
         repository.labelResource(document, 'First Version')
@@ -634,42 +611,40 @@ class VersionControlTests(unittest.TestCase):
         # Make sure the "get version of resource" api is working.
         doc_copy = repository.getVersionOfResource(
             info.history_id, first_version
-            )
+        )
         info = repository.getVersionInfo(doc_copy)
-        self.assertTrue(info.version_id == first_version)
-        self.assertTrue(info.sticky == ('V', first_version))
-        self.assertTrue(document._p_oid != doc_copy._p_oid)
-        self.assertTrue(document is not doc_copy)
+        self.assertEqual(info.version_id, first_version)
+        self.assertEqual(info.sticky, ('V', first_version))
+        self.assertNotEqual(document._p_oid, doc_copy._p_oid)
+        self.assertIsNot(document, doc_copy)
 
         doc_copy = repository.getVersionOfResource(
             info.history_id, "First Version"
-            )
+        )
         info = repository.getVersionInfo(doc_copy)
-        self.assertTrue(info.version_id == first_version)
-        self.assertTrue(info.sticky == ('L', 'First Version'))
-        self.assertTrue(document._p_oid != doc_copy._p_oid)
-        self.assertTrue(document is not doc_copy)
-
+        self.assertEqual(info.version_id, first_version)
+        self.assertEqual(info.sticky, ('L', 'First Version'))
+        self.assertNotEqual(document._p_oid, doc_copy._p_oid)
+        self.assertIsNot(document, doc_copy)
 
     def testDetectPersistentSubObjectChange(self):
         # Test detection of changes to persistent sub-objects.
         repository = self.repository
         folder2 = self.folder2
-        document = self.document1
 
         # Place a resource w/ persistent subobjects under version control.
         repository.applyVersionControl(folder2)
-        get_transaction().commit()
+        transaction.commit()
 
         document1 = getattr(folder2, 'document1')
         document1.manage_edit('spam spam', '')
-        get_transaction().commit()
+        transaction.commit()
 
         self.assertTrue(repository.isResourceChanged(folder2))
 
-
     def testContainerVersioning(self):
         from OFS.DTMLDocument import addDTMLDocument
+
         # Verify that containers and items are versioned independently.
         repository = self.repository
         folder1 = self.app.folder1
@@ -677,15 +652,15 @@ class VersionControlTests(unittest.TestCase):
         folder1.testattr = 'container_v1'
         folder2.testattr = 'item_v1'
 
-        self.assert_(not repository.isUnderVersionControl(folder1))
+        self.assertFalse(repository.isUnderVersionControl(folder1))
         repository.applyVersionControl(folder1)
         folder1 = self.app.folder1
-        self.assert_(repository.isUnderVersionControl(folder1))
-        self.assert_(not repository.isUnderVersionControl(folder2))
+        self.assertTrue(repository.isUnderVersionControl(folder1))
+        self.assertFalse(repository.isUnderVersionControl(folder2))
         repository.applyVersionControl(folder2)
         folder2 = folder1.folder2
-        self.assert_(repository.isUnderVersionControl(folder2))
-        self.assert_(not repository.isUnderVersionControl(folder2.document1))
+        self.assertTrue(repository.isUnderVersionControl(folder2))
+        self.assertFalse(repository.isUnderVersionControl(folder2.document1))
 
         # Make the first version of folder1 and check it in.
         repository.checkoutResource(folder1)
@@ -718,8 +693,8 @@ class VersionControlTests(unittest.TestCase):
         self.assertEqual(folder2.testattr, 'item_v2')
 
         # Verify that document3 remains an item of the reverted folder1.
-        self.assert_(hasattr(folder1, 'document3'))
-        self.assert_(str(folder1.document3) == 'some more text')
+        self.assertTrue(hasattr(folder1, 'document3'))
+        self.assertEqual(str(folder1.document3), 'some more text')
 
         # Remove document3 and verify that it doesn't reappear upon revert.
         folder1._delObject('document3')
@@ -727,15 +702,14 @@ class VersionControlTests(unittest.TestCase):
         folder1 = self.app.folder1
         self.assertEqual(folder1.testattr, 'container_v2')
         self.assertEqual(folder1.folder2.testattr, 'item_v2')
-        self.assert_(not hasattr(folder1, 'document3'))
-
+        self.assertFalse(hasattr(folder1, 'document3'))
 
     def testNonVersionedAttribute(self):
         # Test a non-version-controlled attribute mixed with
         # a version-controlled attribute.
         self.document1.extra_attr = 'v1'
         self.document1.__vc_ignore__ = ('__ac_local_roles__',)
-        self.document1.__ac_local_roles__ = {'sam': ['Manager',]}
+        self.document1.__ac_local_roles__ = {'sam': ['Manager', ]}
         repository = self.repository
         document = repository.applyVersionControl(self.document1)
         info = repository.getVersionInfo(document)
@@ -753,7 +727,7 @@ class VersionControlTests(unittest.TestCase):
         # that is acquired does not cause an error
         self.document1.__vc_ignore__ = ('dummy_attr',)
         self.folder1.dummy_attr = 'dummy_attr'
-        self.assertEqual( self.folder1.dummy_attr, self.document1.dummy_attr )
+        self.assertEqual(self.folder1.dummy_attr, self.document1.dummy_attr)
 
         repository = self.repository
         document = repository.applyVersionControl(self.document1)
@@ -764,17 +738,15 @@ class VersionControlTests(unittest.TestCase):
         repository.checkinResource(document)
         repository.updateResource(document, first_version)
 
+
 class VersionControlTestsWithCommits(VersionControlTests):
     """Version control test suite with transaction commits that mimic
        the transaction commits that you would get with Web based usage."""
     do_commits = 1
 
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(VersionControlTests))
     suite.addTest(unittest.makeSuite(VersionControlTestsWithCommits))
     return suite
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
-
